@@ -45,6 +45,7 @@
 #'  is chosen), some columns will also be excluded from the filter.
 #'
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' set.seed(3535)
@@ -180,23 +181,29 @@ corr_filter <-
     if (any(!complete.cases(x))) {
       all_na <- apply(x, 2, function(x) all(is.na(x)))
       if (sum(all_na) >= nrow(x) - 1) {
-        warning("Too many correlations are `NA`; skipping correlation filter.",
-                call. = FALSE)
+        rlang::warn("Too many correlations are `NA`; skipping correlation filter.")
         return(numeric(0))
       } else {
         na_cols <- which(all_na)
         if (length(na_cols) >  0) {
           x[na_cols, ] <- 0
           x[, na_cols] <- 0
-          warning("The correlation matrix has missing values. ",
-                  length(na_cols), " columns were excluded from the filter.",
-                  call. = FALSE)
+          rlang::warn(
+            paste0(
+              "The correlation matrix has missing values. ",
+              length(na_cols),
+              " columns were excluded from the filter."
+            )
+          )
         }
       }
       if (any(is.na(x))) {
-        warning("The correlation matrix has sporadic missing values. ",
-                "Some columns were excluded from the filter.",
-                call. = FALSE)
+        rlang::warn(
+          paste0(
+            "The correlation matrix has sporadic missing values. ",
+            "Some columns were excluded from the filter."
+          )
+        )
         x[is.na(x)] <- 0
       }
       diag(x) <- 1
