@@ -61,13 +61,14 @@
 #' @concept subsampling
 #' @export
 #' @examples
+#' library(modeldata)
 #' data(okc)
 #'
 #' sort(table(okc$diet, useNA = "always"))
 #'
 #' ds_rec <- recipe( ~ ., data = okc) %>%
 #'   step_downsample(diet) %>%
-#'   prep(training = okc, retain = TRUE)
+#'   prep(training = okc)
 #'
 #' table(juice(ds_rec)$diet, useNA = "always")
 #'
@@ -130,9 +131,9 @@ step_downsample_new <-
 prep.step_downsample <- function(x, training, info = NULL, ...) {
   col_name <- terms_select(x$terms, info = info)
   if (length(col_name) != 1)
-    stop("Please select a single factor variable.", call. = FALSE)
+    rlang::abort("Please select a single factor variable.")
   if (!is.factor(training[[col_name]]))
-    stop(col_name, " should be a factor variable.", call. = FALSE)
+    rlang::abort(col_name, " should be a factor variable.")
 
   obs_freq <- table(training[[col_name]])
   minority <- min(obs_freq)
